@@ -12,6 +12,8 @@
 #
 ##############################################################################
 """
-$Id: __init__.py 112992 2010-06-03 08:22:48Z janwijbrand $
+$Id$
 """
-from hurry.query.query import And, Or, Eq, NotEq, Between, In, Ge, Le, Text
+from hurry.query.query import All, And, Or, Eq, NotEq, Difference, Objects, Ids
+from hurry.query.query import Between, In, Ge, Le, Text
+from hurry.query.query import no_results
