@@ -13,7 +13,7 @@
 ##############################################################################
 """Query terms for zc.catalog's SetIndex
 
-$Id: set.py 127010 2012-06-22 13:17:34Z faassen $
+$Id$
 """
 from zc.catalog.interfaces import ISetIndex
 
@@ -28,46 +28,64 @@ class SetTerm(query.IndexTerm):
         return index
 
 
+class All(SetTerm):
+
+    def apply(self, cache, context=None):
+        return self.getIndex(context).apply({'any': None})
+
+    def key(self, context=None):
+        return ('all', self.catalog_name, self.index_name)
+
+
 class AnyOf(SetTerm):
 
     def __init__(self, index_id, values):
         super(AnyOf, self).__init__(index_id)
-        self.values = values
+        self.values = tuple(values)
 
-    def apply(self, context=None):
+    def apply(self, cache, context=None):
         return self.getIndex(context).apply({'any_of': self.values})
 
+    def key(self, context=None):
+        return ('any of', self.catalog_name, self.index_name, self.values)
+
 
 class AllOf(SetTerm):
 
     def __init__(self, index_id, values):
         super(AllOf, self).__init__(index_id)
-        self.values = values
+        self.values = tuple(values)
 
-    def apply(self, context=None):
+    def apply(self, cache, context=None):
         return self.getIndex(context).apply({'all_of': self.values})
 
+    def key(self, context=None):
+        return ('all of', self.catalog_name, self.index_name, self.values)
+
 
 class SetBetween(SetTerm):
 
     def __init__(self, index_id,
                  minimum=None, maximum=None,
-                 include_minimum=False, include_maximum=False):
+                 exclude_min=False, exclude_max=False):
         super(SetBetween, self).__init__(index_id)
-        self.tuple = (minimum, maximum, include_minimum, include_maximum)
+        self.options = (minimum, maximum, exclude_min, exclude_max)
 
-    def apply(self, context=None):
-        return self.getIndex(context).apply({'between': self.tuple})
+    def apply(self, cache, context=None):
+        return self.getIndex(context).apply({'between': self.options})
+
+    def key(self, context=None):
+        return ('between', self.catalog_name, self.index_name, self.options)
 
 
 class ExtentAny(SetTerm):
     """Any ids in the extent that are indexed by this index."""
 
     def __init__(self, index_id, extent):
-        super(Any, self).__init__(index_id)
+        super(ExtentAny, self).__init__(index_id)
         self.extent = extent
 
-    def apply(self, context=None):
+    def apply(self, cache, context=None):
         return self.getIndex(context).apply({'any': self.extent})
 
 
@@ -75,8 +93,8 @@ class ExtentNone(SetTerm):
     """Any ids in the extent that are not indexed by this index."""
 
     def __init__(self, index_id, extent):
-        super(None, self).__init__(index_id)
+        super(ExtentNone, self).__init__(index_id)
         self.extent = extent
 
-    def apply(self, context=None):
+    def apply(self, cache, context=None):
         return self.getIndex(context).apply({'none': self.extent})
